@@ -14,34 +14,36 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 from math import inf, nan
 
 from canonicaljson import (
     encode_canonical_json,
     encode_pretty_printed_json,
+    frozendict_type,
     iterencode_canonical_json,
     iterencode_pretty_printed_json,
     set_json_library,
 )
 
-from frozendict import frozendict
-
 import unittest
 from unittest import mock
 
 
 class TestCanonicalJson(unittest.TestCase):
-    def test_encode_canonical(self):
+    def test_encode_canonical(self) -> None:
         self.assertEqual(encode_canonical_json({}), b"{}")
 
         # ctrl-chars should be encoded.
         self.assertEqual(
-            encode_canonical_json(u"text\u0003\r\n"), b'"text\\u0003\\r\\n"',
+            encode_canonical_json(u"text\u0003\r\n"),
+            b'"text\\u0003\\r\\n"',
         )
 
         # quotes and backslashes should be escaped.
         self.assertEqual(
-            encode_canonical_json(r'"\ test'), b'"\\"\\\\ test"',
+            encode_canonical_json(r'"\ test'),
+            b'"\\"\\\\ test"',
         )
 
         # non-ascii should come out utf8-encoded.
@@ -59,13 +61,14 @@ class TestCanonicalJson(unittest.TestCase):
         # but we need to watch out for 'u1234' after backslash, which should
         # get encoded to an escaped backslash, followed by u1234
         self.assertEqual(
-            encode_canonical_json(u"\\u1234"), b'"\\\\u1234"',
+            encode_canonical_json(u"\\u1234"),
+            b'"\\\\u1234"',
         )
 
         # Iteratively encoding should work.
         self.assertEqual(list(iterencode_canonical_json({})), [b"{}"])
 
-    def test_ascii(self):
+    def test_ascii(self) -> None:
         """
         Ensure the proper ASCII characters are escaped.
 
@@ -92,10 +95,10 @@ class TestCanonicalJson(unittest.TestCase):
         # And other characters are passed unescaped.
         unescaped = [0x20, 0x21] + list(range(0x23, 0x5C)) + list(range(0x5D, 0x7E))
         for c in unescaped:
-            c = chr(c)
-            self.assertEqual(encode_canonical_json(c), b'"' + c.encode("ascii") + b'"')
+            s = chr(c)
+            self.assertEqual(encode_canonical_json(s), b'"' + s.encode("ascii") + b'"')
 
-    def test_encode_pretty_printed(self):
+    def test_encode_pretty_printed(self) -> None:
         self.assertEqual(encode_pretty_printed_json({}), b"{}")
         self.assertEqual(list(iterencode_pretty_printed_json({})), [b"{}"])
 
@@ -105,15 +108,23 @@ class TestCanonicalJson(unittest.TestCase):
             b'{\n    "la merde amus\xc3\xa9e": "\xF0\x9F\x92\xA9"\n}',
         )
 
-    def test_frozen_dict(self):
+    @unittest.skipIf(
+        frozendict_type is None,
+        "If `frozendict` is not available, skip test",
+    )
+    def test_frozen_dict(self) -> None:
+        # For mypy's benefit:
+        assert frozendict_type is not None
         self.assertEqual(
-            encode_canonical_json(frozendict({"a": 1})), b'{"a":1}',
+            encode_canonical_json(frozendict_type({"a": 1})),
+            b'{"a":1}',
         )
         self.assertEqual(
-            encode_pretty_printed_json(frozendict({"a": 1})), b'{\n    "a": 1\n}'
+            encode_pretty_printed_json(frozendict_type({"a": 1})),
+            b'{\n    "a": 1\n}',
         )
 
-    def test_unknown_type(self):
+    def test_unknown_type(self) -> None:
         class Unknown(object):
             pass
 
@@ -124,9 +135,8 @@ class TestCanonicalJson(unittest.TestCase):
         with self.assertRaises(Exception):
             encode_pretty_printed_json(unknown_object)
 
-    def test_invalid_float_values(self):
-        """Infinity/-Infinity/NaN are not allowed in canonicaljson.
-        """
+    def test_invalid_float_values(self) -> None:
+        """Infinity/-Infinity/NaN are not allowed in canonicaljson."""
 
         with self.assertRaises(ValueError):
             encode_canonical_json(inf)
@@ -146,7 +156,7 @@ class TestCanonicalJson(unittest.TestCase):
         with self.assertRaises(ValueError):
             encode_pretty_printed_json(nan)
 
-    def test_set_json(self):
+    def test_set_json(self) -> None:
         """Ensure that changing the underlying JSON implementation works."""
         mock_json = mock.Mock(spec=["JSONEncoder"])
         mock_json.JSONEncoder.return_value.encode.return_value = "sentinel"
@@ -155,6 +165,6 @@ class TestCanonicalJson(unittest.TestCase):
             self.assertEqual(encode_canonical_json({}), b"sentinel")
         finally:
             # Reset the JSON library to whatever was originally set.
-            from canonicaljson import json
+            from canonicaljson import json  # type: ignore[attr-defined]
 
             set_json_library(json)
